@@ -16,4 +16,17 @@ class ParseConfig(object):
     def __init__(self):
         self.level = OutputLevel.ONLY_URL
         self.pretty = False
-        self.encoding = None
\ No newline at end of file
+        self.encoding = None
+
+
+_parse_config = ParseConfig()
+
+
+def set_config(config):
+    global _parse_config
+    _parse_config = config
+
+
+def get_config():
+    global _parse_config
+    return _parse_config
\ No newline at end of file
